@@ -44,6 +44,26 @@
 GST_DEBUG_CATEGORY_STATIC (gst_nv_av1_dec_debug);
 #define GST_CAT_DEFAULT gst_nv_av1_dec_debug
 
+#define DOC_SINK_CAPS \
+    "video/x-av1, width = (int) [ 128, 8192 ], height = (int) [ 128, 8192 ], " \
+    "alignment= (string) frame, " \
+    "profile = (string) main"
+
+#define DOC_SRC_CAPS_COMM \
+    "format = (string) { NV12, P010_10LE }, " \
+    "width = (int) [ 128, 8192 ], height = (int) [ 128, 8192 ]"
+
+#define DOC_SRC_CAPS_D3D11 \
+    "format = (string) { I420, I420_10LE }, " \
+    "width = (int) [ 128, 8192 ], height = (int) [ 128, 8192 ]"
+
+#define DOC_SRC_CAPS \
+    "video/x-raw(memory:CUDAMemory), " DOC_SRC_CAPS_COMM "; " \
+    "video/x-raw(memory:D3D12Memory), " DOC_SRC_CAPS_COMM "; " \
+    "video/x-raw(memory:D3D11Memory), " DOC_SRC_CAPS_D3D11 "; " \
+    "video/x-raw(memory:GLMemory), " DOC_SRC_CAPS_COMM "; " \
+    "video/x-raw, " DOC_SRC_CAPS_COMM
+
 typedef struct _GstNvAV1Dec
 {
   GstAV1Decoder parent;
@@ -229,12 +249,19 @@ gst_nv_av1_dec_class_init (GstNvAV1DecClass * klass,
       "Codec/Decoder/Video/Hardware",
       "NVIDIA AV1 video decoder", "Seungha Yang <seungha@centricular.com>");
 
-  gst_element_class_add_pad_template (element_class,
-      gst_pad_template_new ("sink", GST_PAD_SINK, GST_PAD_ALWAYS,
-          cdata->sink_caps));
-  gst_element_class_add_pad_template (element_class,
-      gst_pad_template_new ("src", GST_PAD_SRC, GST_PAD_ALWAYS,
-          cdata->src_caps));
+  auto pad_templ = gst_pad_template_new ("sink",
+      GST_PAD_SINK, GST_PAD_ALWAYS, cdata->sink_caps);
+  auto doc_caps = gst_caps_from_string (DOC_SINK_CAPS);
+  gst_pad_template_set_documentation_caps (pad_templ, doc_caps);
+  gst_caps_unref (doc_caps);
+  gst_element_class_add_pad_template (element_class, pad_templ);
+
+  pad_templ = gst_pad_template_new ("src",
+      GST_PAD_SRC, GST_PAD_ALWAYS, cdata->src_caps);
+  doc_caps = gst_caps_from_string (DOC_SRC_CAPS);
+  gst_pad_template_set_documentation_caps (pad_templ, doc_caps);
+  gst_caps_unref (doc_caps);
+  gst_element_class_add_pad_template (element_class, pad_templ);
 
   decoder_class->open = GST_DEBUG_FUNCPTR (gst_nv_av1_dec_open);
   decoder_class->close = GST_DEBUG_FUNCPTR (gst_nv_av1_dec_close);
